# -*- coding: utf-8 -*-
from setuphelpers import *

r"""
Usable WAPT package functions: install(), uninstall(), session_setup(), audit(), update_package()

Lifecycle Milestones for Citrix Workspace app:
https://www.citrix.com/support/product-lifecycle/workspace-app.html

CitrixWorkspaceApp.exe /?
Paramètres pris en charge :
/help               - Affiche ces informations d'utilisation
/uninstall          - Supprime une installation existante
/silent             - Supprime toutes les interfaces utilisateur graphiques
/noreboot           - Supprime tous les redémarrages et invites de redémarrage
/preview - Affiche un aperçu des modifications sans modifier la machine
/extract &lt;dossier&gt; - Extrait un pack auto-extractible sur un dossier existant
/includeSSON        - Installe le composant Single Sign-On pour l'ouverture de session unique au domaine
/EnableCEIP         - Active (true) ou désactive (false) le Programme Citrix d'amélioration de la satisfaction client (CEIP)
/AutoUpdateCheck - Active la mise à jour automatique (auto), active la mise à jour manuelle (manual), interdit la mise à jour automatique (disabled)
/AutoUpdateStream - Spécifie le cycle de mise à jour automatique : Long Term Service Release (LTSR) ou Short Term Service Releases (Current)
/DeferUpdateCount - Spécifie le nombre de fois qu'il est possible de différer la mise à jour automatique

Les valeurs de propriété MSI sont prises en charge et doivent être séparées par des espaces, par ex. :
   PROPERTY="Value" PROPERTY2="Valeur2"

Exemple de ligne de commande silencieuse utilisant toutes les valeurs par défaut :
   CitrixWorkspaceApp.exe /silent

Exemple de ligne de commande spécifiant de multiples options :
   CitrixWorkspaceApp.exe /silent ADDLOCAL="ReceiverInside,ICA_Client,USB,DesktopViewer,WebHelper,BrowserEngine" INSTALLDIR="C:\mondossier" ENABLE_DYNAMIC_CLIENT_NAME="No" CLIENT_NAME="mon_nom_remplacé" DEFAULT_NDSCONTEXT="Contexte1,Contexte2"

Exemple de ligne de commande pour activer l'authentification unique au domaine :
   CitrixWorkspaceApp.exe /silent  /includeSSON ADDLOCAL="ReceiverInside,ICA_Client,SSON,USB,DesktopViewer,WebHelper,BrowserEngine" INSTALLDIR="C:\mondossier" ENABLE_DYNAMIC_CLIENT_NAME="No" CLIENT_NAME="mon_nom_remplacé" DEFAULT_NDSCONTEXT="Contexte1,Contexte2"

Exemple de ligne de commande pour installer le serveur Single Sign-On mais pour désactiver la capture des informations d'identification d'ouverture de session :
   CitrixWorkspaceApp.exe /includesson LOGON_CREDENTIAL_CAPTURE_ENABLE=No [valeur par défaut = Yes]

Exemple de ligne de commande pour installer Citrix Workspace en mode non autonome
   CitrixWorkspaceApp.exe SELFSERVICEMODE=false [valeur par défaut = true]

Exemple de ligne de commande destinée à prendre en charge la mise à niveau de versions non prises en charge vers la dernière version
CitrixWorkspaceApp.exe /RCU

Exemple de ligne de commande pour désactiver le programme CEIP :
   CitrixWorkspaceApp.exe /EnableCEIP=false     [valeur par défaut = true]

Exemple de ligne de commande pour activer la mise à jour manuelle :
CitrixWorkspaceApp.exe /AutoUpdateCheck=manual [valeur par défaut = auto]
Exemple de ligne de commande pour désactiver la mise à jour automatique :
CitrixWorkspaceApp.exe /AutoUpdateCheck=disabled

Exemple de ligne de commande pour choisir un cycle Long Term Service Release :
    CitrixWorkspaceApp.exe /AutoUpdateStream=LTSR
Exemple de ligne de commande pour différer la mise à jour automatique à 2 reprises :
    CitrixWorkspaceApp.exe /DeferUpdateCount=2

UninstallKey                           Software                                                              Version             Uninstallstring
-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
CitrixOnlinePluginPackWeb              Citrix Workspace 2202                                                 22.2.0.4525         "C:\Program Files (x86)\Citrix\Citrix WorkSpace 2202\TrolleyExpress.exe" /uninstall /cleanup
{483AD12D-597C-4FEF-9BD4-07805F25A438} Self-Service Plug-in                                                  22.2.0.4512         MsiExec.exe /X{483AD12D-597C-4FEF-9BD4-07805F25A438}
{4D46B3A6-67F5-4385-86D2-8E769EA07827} Citrix Screen Casting for Windows                                     19.11.100.48        MsiExec.exe /I{4D46B3A6-67F5-4385-86D2-8E769EA07827}
{4FC9E161-15ED-4B0B-AA7D-75BCD89168AD} Online Plug-in                                                        22.02.0.15          MsiExec.exe /I{4FC9E161-15ED-4B0B-AA7D-75BCD89168AD}
{7DC29796-8D4D-487D-B84F-BAA2C2BDF5DB} Citrix Workspace (USB)                                                22.02.0.15          MsiExec.exe /I{7DC29796-8D4D-487D-B84F-BAA2C2BDF5DB}
{89B4445F-A487-4A8B-9751-084218ADA856} Citrix Workspace Inside                                               22.2.0.4509         MsiExec.exe /I{89B4445F-A487-4A8B-9751-084218ADA856}
{A151881A-C1D8-4FB5-993E-BE24B91F950F} Citrix WorkSpace Browser                                              22.2.1.4            MsiExec.exe /X{A151881A-C1D8-4FB5-993E-BE24B91F950F}
{ECA0F1A0-DB79-46C1-82A1-C123B6B61608} Citrix Workspace (DV)                                                 22.02.0.15          MsiExec.exe /X{ECA0F1A0-DB79-46C1-82A1-C123B6B61608}
{F010EB2B-C3E2-49A4-884E-D0A65C34D63D} Citrix Web Helper                                                     22.2.0.4512         MsiExec.exe /X{F010EB2B-C3E2-49A4-884E-D0A65C34D63D}
{F7179C2E-7F98-4DBE-95F8-612F933D9A6E} Citrix Authentication Manager                                         22.2.1.2            MsiExec.exe /X{F7179C2E-7F98-4DBE-95F8-612F933D9A6E}


"""
# Declaring global variables - Warnings: 1) WAPT context is only available in package functions; 2) Global variables are not persistent between calls


def install():
    install_exe_if_needed(
        "CitrixWorkspaceApp.exe",
        silentflags="/AutoUpdateCheck=disabled /EnableCEIP=false /silent /noreboot",
        key="CitrixOnlinePluginPackWeb",
        min_version=control.version.split("-", 1)[0],
        timeout=900,
    )

    # Adding QuietUninstallString for app
    register_uninstall(
        "CitrixOnlinePluginPackWeb",
        quiet_uninstall_string=installed_softwares(uninstallkey="CitrixOnlinePluginPackWeb")[0]["uninstall_string"] + " /silent /noreboot",
    )


def uninstall():
    # Windows 11 remaining key
    # {dcdaa2fd-eaac-4ab0-9ece-f3df127a6c45}.sdb     Citrix Workspace     %windir%\system32\sdbinst.exe -u "C:\Windows\AppPatch\CustomSDB\{dcdaa2fd-eaac-4ab0-9ece-f3df127a6c45}.sdb"
    for to_uninstall in installed_softwares(uninstallkey="{dcdaa2fd-eaac-4ab0-9ece-f3df127a6c45}.sdb"):
        print("Removing: %s (%s)" % (to_uninstall["name"], to_uninstall["version"]))
        killalltasks(control.get_impacted_process_list())
        app_uninstall_cmd = '"%s" -u "C:\Windows\AppPatch\CustomSDB\{dcdaa2fd-eaac-4ab0-9ece-f3df127a6c45}.sdb"' % makepath(
            os.environ["SYSTEMROOT"], "system32", "sdbinst.exe"
        )
        run(app_uninstall_cmd, accept_returncodes=[0, 3010])
        wait_uninstallkey_absent(to_uninstall["key"])
